@@ -11,5 +11,15 @@ __docformat__ = "reStructureText"
 
 from geospacelab.config._preferences import Preferences
 
+pref = Preferences()
+
+try:
+    opt = pref.user_config['visualization']
+except KeyError:
+    uc = pref.user_config
+    uc['visualization'] = dict()
+    uc['visualization']['mpl'] = dict()
+    pref.set_user_config(user_config=uc, set_as_default=True)
+
 
 
