@@ -111,17 +111,20 @@ class MillstoneHillISRDashboard(TSDashboard):
                     sequence_str = repr(beams_sequence_inds[ind][:10]).replace(']', ', ...]')
                 mylog.simpleinfo.info(
                     '{:^20d}{:^20s}{:^20d}{:80s}'.format(
-                        ind+1, f"({beams[ind, 0]}, {beams[ind, 1]})", beams_counts[ind], sequence_str
+                        ind+1, f"({'{:.1f}'.format(beams[ind, 0])}, {'{:.1f}'.format(beams[ind, 1])})",
+                        beams_counts[ind], sequence_str
                     )
                 )
 
         return beams, beams_counts, beams_sequence_inds
 
-    def save_figure(self, **kwargs):
-        file_name = kwargs.pop('file_name', self.title.replace(', ', '_').replace(': ', '_'))
-        super().save_figure(file_name=file_name, **kwargs)
+    def save_figure(self, file_name=None, file_dir=None, append_time=True, **kwargs):
+        if file_name is None:
+            file_name = kwargs.pop('file_name', self.title.replace(', ', '_'))
+        super().save_figure(file_name=file_name, file_dir=file_dir, append_time=append_time, **kwargs)
+
+    def add_title(self, x=0.5, y=1.06, title=None, append_time=True, **kwargs):
 
-    def add_title(self, **kwargs):
         if self.az is not None and self.el is not None:
             azstr = 'az: {:.1f}'.format(self.az)
             elstr = 'el: {:.1f}'.format(self.el)
@@ -132,8 +135,9 @@ class MillstoneHillISRDashboard(TSDashboard):
             self.host_dataset.facility, self.host_dataset.antenna,
             self.host_dataset.pulse_code, r'PL: {:.1f}'.format(self.host_dataset.pulse_length), azstr, elstr
             ], separator=', '))
-        title = kwargs.pop('title', self.title)
-        super().add_title(x=0.5, y=1.06, title=title)
+        if title is None:
+            title = self.title
+        super().add_title(x=x, y=y, title=title, append_time=append_time, **kwargs)
 
     def quicklook(self):
         n_e = self.assign_variable('n_e')
@@ -159,29 +163,3 @@ class MillstoneHillISRDashboard(TSDashboard):
         self.add_panel_labels()
 
 
-def example(dt_fr, dt_to):
-
-    #dt_fr = datetime.datetime.strptime('20160315' + '1200', '%Y%m%d%H%M')
-    #dt_to = datetime.datetime.strptime('20160316' + '1200', '%Y%m%d%H%M')
-
-    antenna = 'misa'
-    pulse_code = 'alternating'
-    pulse_length = 480
-    load_mode = 'AUTO'
-    dashboard = MillstoneHillISRDashboard(
-        dt_fr, dt_to, antenna=antenna, pulse_code=pulse_code, pulse_length=pulse_length,
-    )
-    dashboard.select_beams(az_el_pairs=[[-40.5, 45]])
-    dashboard.quicklook()
-    dashboard.save_figure()
-    # dashboard.show()
-
-def example2():
-
-    for i in range(6):
-        dt0 = datetime.datetime(2016, 3, 13)
-        example(dt_fr=dt0 + datetime.timedelta(days=i, hours=12), dt_to = dt0 + datetime.timedelta(days=i+1, hours=12))
-
-if __name__ == '__main__':
-    example2()
-
